Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(456)

Unified Diff: dart/editor/tools/plugins/com.google.dart.engine/src/com/google/dart/engine/internal/resolver/ProxyConditionalAnalysisError.java

Issue 59073003: Version 0.8.10.4 (Closed) Base URL: http://dart.googlecode.com/svn/trunk/
Patch Set: Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: dart/editor/tools/plugins/com.google.dart.engine/src/com/google/dart/engine/internal/resolver/ProxyConditionalAnalysisError.java
===================================================================
--- dart/editor/tools/plugins/com.google.dart.engine/src/com/google/dart/engine/internal/resolver/ProxyConditionalAnalysisError.java (revision 29808)
+++ dart/editor/tools/plugins/com.google.dart.engine/src/com/google/dart/engine/internal/resolver/ProxyConditionalAnalysisError.java (working copy)
@@ -31,16 +31,11 @@
public class ProxyConditionalAnalysisError {
/**
* The name of the proxy annotation, from the meta pub package.
*/
private static final String PROXY_ANNOTATION_NAME = "proxy";
/**
- * The name of the meta library name, from the meta pub package.
- */
- private static final String META_LIBRARY_NAME = "meta";
-
- /**
* Return {@code true} if the given element represents a class that has the proxy annotation.
*
* @param element the class being tested
@@ -54,8 +49,8 @@
Element elementAnnotation = annotation.getElement();
if (elementAnnotation != null) {
LibraryElement lib = elementAnnotation.getLibrary();
- if (elementAnnotation.getName().equals(PROXY_ANNOTATION_NAME) && lib != null
- && lib.getName().equals(META_LIBRARY_NAME)) {
+ if (lib != null && lib.isDartCore()
+ && elementAnnotation.getName().equals(PROXY_ANNOTATION_NAME)) {
return true;
}
}
@@ -31,16 +31,11 @@
public class ProxyConditionalAnalysisError {
/**
- * The name of the proxy annotation, from the meta pub package.
+ * The name of the proxy annotation, from dart:core.
*/
private static final String PROXY_ANNOTATION_NAME = "proxy";

Powered by Google App Engine
This is Rietveld 408576698